Translate Toolkit 1.5.1 — Translate Toolkit 2.4.0 documentation

Translate Toolkit 2.4.0

- Site
  - Features
  - Installation
  - Converters
  - Tools
  - Scripts
  - Use Cases
  - Supported formats
  - Translate Styleguide
  - Documentation
  - Building
  - Testing
  - Command Line Functional Testing
  - Contributing
  - Translate Toolkit Developers Guide
  - Making a Translate Toolkit Release
  - Deprecation of Features
  - Release Notes
  - History of the Translate Toolkit
  - License
  - API
- Page
  - Translate Toolkit 1.5.1
- « Translate Toolkit 1.5.2
- Translate Toolkit 1.5.0 »

# Translate Toolkit 1.5.1

Released on 8 December 2009

Release notes for this release are still to be recovered, feel free to do some way back searching and create a Pull Request for this release.